==> quanyi-center-api-1.1.58-merge-20240909.033525-46-sources.jar: cn/com/duiba/quanyi/center/api/param/mall/order/MallPayCreateOrderParam.java <==
package cn.com.duiba.quanyi.center.api.param.mall.order;

import cn.com.duiba.quanyi.center.api.dto.goods.ext.TakeParamDto;
import cn.com.duiba.quanyi.center.api.enums.pay.PayChannelTypeEnum;
import cn.com.duiba.quanyi.center.api.param.pay.ext.InsuranceFundCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.PsbcPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.WxLiteCreateOrderParam;
import lombok.Data;

import java.io.Serializable;

/**
 * 商城支付创建订单参数
 * @author lizhi
 * @date 2023/8/7 18:20
 */
@Data
public class MallPayCreateOrderParam implements Serializable {
    
    private static final long serialVersionUID = 8894539309360592962L;

    /**
     * 配置ID
     */
    private Long confId;

    /**
     * 商城商品Id
     */
    private Long mallSpuId;

    /**
     * 商城商品Id
     */
    private Long mallSkuId;

    /**
     * 数量
     */
    private Integer quantity;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * appId
     */
    private String appId;

    /**
     * 页面展示需要支付的金额
     */
    private Long pageAmount;

    /**
     * 支付渠道
     * @see cn.com.duiba.quanyi.center.api.enums.pay.PayChannelTypeEnum
     */
    private String payChannelType = PayChannelTypeEnum.WX_LITE.getChannelType();

    /**
     * 收货地址ID，实物时必填
     */
    private Long addressId;

    /**
     * 直充领取参数
     */
    private TakeParamDto takeParam;

    /**
     * 微信小程序支付参数
     */
    private WxLiteCreateOrderParam wxLite;

    /**
     * 保司资金账户
     */
    private InsuranceFundCreateOrderParam insuranceFund;

    /**
     * 邮储银行支付参数
     */
    private PsbcPayCreateOrderParam psbcPay;
}

==> quanyi-center-api-1.1.65-merge-20240913.090506-1-sources.jar: cn/com/duiba/quanyi/center/api/param/mall/order/MallPayCreateOrderParam.java <==
package cn.com.duiba.quanyi.center.api.param.mall.order;

import cn.com.duiba.quanyi.center.api.enums.pay.PayChannelTypeEnum;
import cn.com.duiba.quanyi.center.api.param.pay.ext.InsuranceFundCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.PsbcPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.WxLiteCreateOrderParam;
import lombok.Data;

import java.io.Serializable;

/**
 * 商城支付创建订单参数
 * @author lizhi
 * @date 2023/8/7 18:20
 */
@Data
public class MallPayCreateOrderParam implements Serializable {
    
    private static final long serialVersionUID = 8894539309360592962L;

    /**
     * 配置ID
     */
    private Long confId;

    /**
     * 商城商品Id
     */
    private Long mallSpuId;

    /**
     * 商城商品Id
     */
    private Long mallSkuId;

    /**
     * 数量
     */
    private Integer quantity;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * appId
     */
    private String appId;

    /**
     * 页面展示需要支付的金额
     */
    private Long pageAmount;

    /**
     * 支付渠道
     * @see cn.com.duiba.quanyi.center.api.enums.pay.PayChannelTypeEnum
     */
    private String payChannelType = PayChannelTypeEnum.WX_LITE.getChannelType();

    /**
     * 收货地址ID，实物时必填
     */
    private Long addressId;

    /**
     * 支付宝用户id，可通过支付宝授权方式获取
     */
    private String alipayUserId;

    /**
     * 支付宝openId, 映射支付宝user_id
     * 请使用open_id，后续user_id将不支持新接入使用，存量已对接的也将逐步回收。
     */
    private String alipayOpenId;

    /**
     * 支付宝登录账号，邮箱格式
     */
    private String alipayLoginId;

    /**
     * 支付宝登录账号，手机号格式
     */
    private String alipayPhoneId;

    /**
     * 充值手机号
     * 爱奇艺、腾讯会员
     */
    private String phone;

    /**
     * 充值账号
     * ● 商品为油卡时有值
     */
    private String account;

    /**
     * 充值qq号
     */
    private String qqAccount;


    /**
     * 微信小程序支付参数
     */
    private WxLiteCreateOrderParam wxLite;

    /**
     * 保司资金账户
     */
    private InsuranceFundCreateOrderParam insuranceFund;

    /**
     * 车牌号 商品类型为车服必填
     */
    private String carNumber;

    /**
     * 手机号 商品类型为车服必填
     */
    private String userPhone;

    /**
     * 门店服务id，汽车服务时必填
     */
    private Long storeSerId;

    /**
     * 汽车服务名称
     */
    private String carSerName;

    /**
     * 门店id，汽车服务时必填
     */
    private Long storeId;

    /**
     * 邮储银行支付参数
     */
    private PsbcPayCreateOrderParam psbcPay;
}
